Publications
============

**Chicago**

    Allen-Dumas, M. R., Rose, A. N., New, J. R., Omitaomu, O. A., Yuan, J., Branstetter, M. L., ... & Kahl, A. C. (2020). Impacts of the morphology of new neighborhoods on microclimate and building energy. Renewable and Sustainable Energy Reviews, 133, 110030.
